Module :mod:`mididings.engine`
==============================

This module contains functions to query or control the state of the mididings
event processing engine from Python code.

.. automodule:: mididings.engine
    :exclude-members: run, process_file, Engine
